# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .llm_response import LlmResponse

__all__ = ["LlmListResponse"]

LlmListResponse: TypeAlias = List[LlmResponse]
